@@ -1,11 +1,12 @@
-use 5.14.0; # Due to Stenciller
+use 5.10.0;
 use strict;
 use warnings;
 
 package Stenciller::Plugin::ToMojoliciousTest;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102';
 # ABSTRACT: Create Mojolicious tests from text files parsed with Stenciller
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
 
 use Moose;
 use Types::Path::Tiny qw/Path/;
@@ -18,7 +19,6 @@ has template => (
     coerce => 1,
 );
 
-
 sub transform {
     my $self = shift;
     my $transform_args = shift;
@@ -69,8 +69,6 @@ sub transform {
     return $template.$content;
 }
 
-
-
 1;
 
 __END__
@@ -85,22 +83,21 @@ Stenciller::Plugin::ToMojoliciousTest - Create Mojolicious tests from text files
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest"><img src="https://api.travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest"><img src="https://api.travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Stenciller-Plugin-ToMojoliciousTest-0.0102"><img src="https://badgedepot.code301.com/badge/kwalitee/Stenciller-Plugin-ToMojoliciousTest/0.0102" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Stenciller-Plugin-ToMojoliciousTest%200.0102"><img src="https://badgedepot.code301.com/badge/cpantesters/Stenciller-Plugin-ToMojoliciousTest/0.0102" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-94.0%-yellow.svg" alt="coverage 94.0%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest.svg?branch=master)](https://travis-ci.org/Csson/p5-Stenciller-Plugin-ToMojoliciousTest)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.0101, released 2015-11-23.
+Version 0.0102, released 2016-03-23.
 
 =head1 SYNOPSIS
 
@@ -218,7 +215,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
